==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/sql/kotlin/SqlVulnerabilityAssessmentRuleBaselineArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.sql.kotlin

import com.pulumi.azurenative.sql.SqlVulnerabilityAssessmentRuleBaselineArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * A database sql vulnerability assessment rule baseline.
 * Azure REST API version: 2022-11-01-preview.
 * Other available API versions: 2023-02-01-preview, 2023-05-01-preview.
 * ## Example Usage
 * ### Creates or updates a database's vulnerability assessment rule baseline.
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var sqlVulnerabilityAssessmentRuleBaseline = new AzureNative.Sql.SqlVulnerabilityAssessmentRuleBaseline("sqlVulnerabilityAssessmentRuleBaseline", new()
 *     {
 *         BaselineName = "default",
 *         LatestScan = false,
 *         ResourceGroupName = "vulnerabilityaseessmenttest-4799",
 *         Results = new[]
 *         {
 *             new[]
 *             {
 *                 "userA",
 *                 "SELECT",
 *             },
 *             new[]
 *             {
 *                 "userB",
 *                 "SELECT",
 *             },
 *             new[]
 *             {
 *                 "userC",
 *                 "SELECT",
 *             },
 *         },
 *         RuleId = "VA1001",
 *         ServerName = "vulnerabilityaseessmenttest-6440",
 *         SystemDatabaseName = "master",
 *         VulnerabilityAssessmentName = "default",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/sql/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := sql.NewSqlVulnerabilityAssessmentRuleBaseline(ctx, "sqlVulnerabilityAssessmentRuleBaseline", &sql.SqlVulnerabilityAssessmentRuleBaselineArgs{
 * 			BaselineName:      pulumi.String("default"),
 * 			LatestScan:        pulumi.Bool(false),
 * 			ResourceGroupName: pulumi.String("vulnerabilityaseessmenttest-4799"),
 * 			Results: pulumi.StringArrayArray{
 * 				pulumi.StringArray{
 * 					pulumi.String("userA"),
 * 					pulumi.String("SELECT"),
 * 				},
 * 				pulumi.StringArray{
 * 					pulumi.String("userB"),
 * 					pulumi.String("SELECT"),
 * 				},
 * 				pulumi.StringArray{
 * 					pulumi.String("userC"),
 * 					pulumi.String("SELECT"),
 * 				},
 * 			},
 * 			RuleId:                      pulumi.String("VA1001"),
 * 			ServerName:                  pulumi.String("vulnerabilityaseessmenttest-6440"),
 * 			SystemDatabaseName:          pulumi.String("master"),
 * 			VulnerabilityAssessmentName: pulumi.String("default"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.sql.SqlVulnerabilityAssessmentRuleBaseline;
 * import com.pulumi.azurenative.sql.SqlVulnerabilityAssessmentRuleBaselineArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var sqlVulnerabilityAssessmentRuleBaseline = new SqlVulnerabilityAssessmentRuleBaseline("sqlVulnerabilityAssessmentRuleBaseline", SqlVulnerabilityAssessmentRuleBaselineArgs.builder()
 *             .baselineName("default")
 *             .latestScan(false)
 *             .resourceGroupName("vulnerabilityaseessmenttest-4799")
 *             .results(
 *                     "userA",
 *                     "SELECT",
 *                     "userB",
 *                     "SELECT",
 *                     "userC",
 *                     "SELECT")
 *             .ruleId("VA1001")
 *             .serverName("vulnerabilityaseessmenttest-6440")
 *             .systemDatabaseName("master")
 *             .vulnerabilityAssessmentName("default")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:sql:SqlVulnerabilityAssessmentRuleBaseline Scan123 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Sql/servers/{serverName}/sqlVulnerabilityAssessments/{vulnerabilityAssessmentName}/baselines/{baselineName}/rules/{ruleId}
 * ```
 * @property baselineName
 * @property latestScan The latest scan flag
 * @property resourceGroupName The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
 * @property results The rule baseline result
 * @property ruleId The vulnerability assessment rule ID.
 * @property serverName The name of the server.
 * @property systemDatabaseName The vulnerability assessment system database name.
 * @property vulnerabilityAssessmentName The name of the vulnerability assessment.
 */
public data class SqlVulnerabilityAssessmentRuleBaselineArgs(
    public val baselineName: Output<String>? = null,
    public val latestScan: Output<Boolean>? = null,
    public val resourceGroupName: Output<String>? = null,
    public val results: Output<List<List<String>>>? = null,
    public val ruleId: Output<String>? = null,
    public val serverName: Output<String>? = null,
    public val systemDatabaseName: Output<String>? = null,
    public val vulnerabilityAssessmentName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.sql.SqlVulnerabilityAssessmentRuleBaselineArgs> {
    override fun toJava(): com.pulumi.azurenative.sql.SqlVulnerabilityAssessmentRuleBaselineArgs =
        com.pulumi.azurenative.sql.SqlVulnerabilityAssessmentRuleBaselineArgs.builder()
            .baselineName(baselineName?.applyValue({ args0 -> args0 }))
            .latestScan(latestScan?.applyValue({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 }))
            .results(results?.applyValue({ args0 -> args0.map({ args0 -> args0.map({ args0 -> args0 }) }) }))
            .ruleId(ruleId?.applyValue({ args0 -> args0 }))
            .serverName(serverName?.applyValue({ args0 -> args0 }))
            .systemDatabaseName(systemDatabaseName?.applyValue({ args0 -> args0 }))
            .vulnerabilityAssessmentName(vulnerabilityAssessmentName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SqlVulnerabilityAssessmentRuleBaselineArgs].
 */
@PulumiTagMarker
public class SqlVulnerabilityAssessmentRuleBaselineArgsBuilder internal constructor() {
    private var baselineName: Output<String>? = null

    private var latestScan: Output<Boolean>? = null

    private var resourceGroupName: Output<String>? = null

    private var results: Output<List<List<String>>>? = null

    private var ruleId: Output<String>? = null

    private var serverName: Output<String>? = null

    private var systemDatabaseName: Output<String>? = null

    private var vulnerabilityAssessmentName: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("oxbrnjhvuwkojhtc")
    public suspend fun baselineName(`value`: Output<String>) {
        this.baselineName = value
    }

    /**
     * @param value The latest scan flag
     */
    @JvmName("nptafqxqsbwqclap")
    public suspend fun latestScan(`value`: Output<Boolean>) {
        this.latestScan = value
    }

    /**
     * @param value The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
     */
    @JvmName("aibuxuoedqtlwmbf")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value The rule baseline result
     */
    @JvmName("wddxpfuwguytqxin")
    public suspend fun results(`value`: Output<List<List<String>>>) {
        this.results = value
    }

    @JvmName("rpfvlrswkdrbqgjw")
    public suspend fun results(vararg values: Output<List<String>>) {
        this.results = Output.all(values.asList())
    }

    /**
     * @param values The rule baseline result
     */
    @JvmName("xjoqocskpadlodpo")
    public suspend fun results(values: List<Output<List<String>>>) {
        this.results = Output.all(values)
    }

    /**
     * @param value The vulnerability assessment rule ID.
     */
    @JvmName("djkiikrlemjrjcbn")
    public suspend fun ruleId(`value`: Output<String>) {
        this.ruleId = value
    }

    /**
     * @param value The name of the server.
     */
    @JvmName("yhjavyxwktspahgt")
    public suspend fun serverName(`value`: Output<String>) {
        this.serverName = value
    }

    /**
     * @param value The vulnerability assessment system database name.
     */
    @JvmName("fvkgwpxgraqlhpah")
    public suspend fun systemDatabaseName(`value`: Output<String>) {
        this.systemDatabaseName = value
    }

    /**
     * @param value The name of the vulnerability assessment.
     */
    @JvmName("yeewsmmhhlhmvblw")
    public suspend fun vulnerabilityAssessmentName(`value`: Output<String>) {
        this.vulnerabilityAssessmentName = value
    }

    /**
     * @param value
     */
    @JvmName("rwauckripilccuxr")
    public suspend fun baselineName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.baselineName = mapped
    }

    /**
     * @param value The latest scan flag
     */
    @JvmName("kfwwlgnmavbotcwm")
    public suspend fun latestScan(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.latestScan = mapped
    }

    /**
     * @param value The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
     */
    @JvmName("gcytyikujrcaxvhm")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The rule baseline result
     */
    @JvmName("qrneitksomjxxrtq")
    public suspend fun results(`value`: List<List<String>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.results = mapped
    }

    /**
     * @param values The rule baseline result
     */
    @JvmName("pbctstxynmtgknkb")
    public suspend fun results(vararg values: List<String>) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.results = mapped
    }

    /**
     * @param value The vulnerability assessment rule ID.
     */
    @JvmName("ipgqxerpgyhqlxyi")
    public suspend fun ruleId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ruleId = mapped
    }

    /**
     * @param value The name of the server.
     */
    @JvmName("ycrlbfcnnjtcnnpk")
    public suspend fun serverName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serverName = mapped
    }

    /**
     * @param value The vulnerability assessment system database name.
     */
    @JvmName("axumgxjtymseurtd")
    public suspend fun systemDatabaseName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.systemDatabaseName = mapped
    }

    /**
     * @param value The name of the vulnerability assessment.
     */
    @JvmName("lydlfvyufdcxsrxa")
    public suspend fun vulnerabilityAssessmentName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.vulnerabilityAssessmentName = mapped
    }

    internal fun build(): SqlVulnerabilityAssessmentRuleBaselineArgs =
        SqlVulnerabilityAssessmentRuleBaselineArgs(
            baselineName = baselineName,
            latestScan = latestScan,
            resourceGroupName = resourceGroupName,
            results = results,
            ruleId = ruleId,
            serverName = serverName,
            systemDatabaseName = systemDatabaseName,
            vulnerabilityAssessmentName = vulnerabilityAssessmentName,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/sql/kotlin/SqlVulnerabilityAssessmentRuleBaselineArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.sql.kotlin

import com.pulumi.azurenative.sql.SqlVulnerabilityAssessmentRuleBaselineArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * A database sql vulnerability assessment rule baseline.
 * Azure REST API version: 2022-11-01-preview.
 * Other available API versions: 2023-02-01-preview, 2023-05-01-preview.
 * ## Example Usage
 * ### Creates or updates a database's vulnerability assessment rule baseline.
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var sqlVulnerabilityAssessmentRuleBaseline = new AzureNative.Sql.SqlVulnerabilityAssessmentRuleBaseline("sqlVulnerabilityAssessmentRuleBaseline", new()
 *     {
 *         BaselineName = "default",
 *         LatestScan = false,
 *         ResourceGroupName = "vulnerabilityaseessmenttest-4799",
 *         Results = new[]
 *         {
 *             new[]
 *             {
 *                 "userA",
 *                 "SELECT",
 *             },
 *             new[]
 *             {
 *                 "userB",
 *                 "SELECT",
 *             },
 *             new[]
 *             {
 *                 "userC",
 *                 "SELECT",
 *             },
 *         },
 *         RuleId = "VA1001",
 *         ServerName = "vulnerabilityaseessmenttest-6440",
 *         SystemDatabaseName = "master",
 *         VulnerabilityAssessmentName = "default",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/sql/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := sql.NewSqlVulnerabilityAssessmentRuleBaseline(ctx, "sqlVulnerabilityAssessmentRuleBaseline", &sql.SqlVulnerabilityAssessmentRuleBaselineArgs{
 * 			BaselineName:      pulumi.String("default"),
 * 			LatestScan:        pulumi.Bool(false),
 * 			ResourceGroupName: pulumi.String("vulnerabilityaseessmenttest-4799"),
 * 			Results: pulumi.StringArrayArray{
 * 				pulumi.StringArray{
 * 					pulumi.String("userA"),
 * 					pulumi.String("SELECT"),
 * 				},
 * 				pulumi.StringArray{
 * 					pulumi.String("userB"),
 * 					pulumi.String("SELECT"),
 * 				},
 * 				pulumi.StringArray{
 * 					pulumi.String("userC"),
 * 					pulumi.String("SELECT"),
 * 				},
 * 			},
 * 			RuleId:                      pulumi.String("VA1001"),
 * 			ServerName:                  pulumi.String("vulnerabilityaseessmenttest-6440"),
 * 			SystemDatabaseName:          pulumi.String("master"),
 * 			VulnerabilityAssessmentName: pulumi.String("default"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.sql.SqlVulnerabilityAssessmentRuleBaseline;
 * import com.pulumi.azurenative.sql.SqlVulnerabilityAssessmentRuleBaselineArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var sqlVulnerabilityAssessmentRuleBaseline = new SqlVulnerabilityAssessmentRuleBaseline("sqlVulnerabilityAssessmentRuleBaseline", SqlVulnerabilityAssessmentRuleBaselineArgs.builder()
 *             .baselineName("default")
 *             .latestScan(false)
 *             .resourceGroupName("vulnerabilityaseessmenttest-4799")
 *             .results(
 *                     "userA",
 *                     "SELECT",
 *                     "userB",
 *                     "SELECT",
 *                     "userC",
 *                     "SELECT")
 *             .ruleId("VA1001")
 *             .serverName("vulnerabilityaseessmenttest-6440")
 *             .systemDatabaseName("master")
 *             .vulnerabilityAssessmentName("default")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:sql:SqlVulnerabilityAssessmentRuleBaseline Scan123 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Sql/servers/{serverName}/sqlVulnerabilityAssessments/{vulnerabilityAssessmentName}/baselines/{baselineName}/rules/{ruleId}
 * ```
 * @property baselineName
 * @property latestScan The latest scan flag
 * @property resourceGroupName The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
 * @property results The rule baseline result
 * @property ruleId The vulnerability assessment rule ID.
 * @property serverName The name of the server.
 * @property systemDatabaseName The vulnerability assessment system database name.
 * @property vulnerabilityAssessmentName The name of the vulnerability assessment.
 */
public data class SqlVulnerabilityAssessmentRuleBaselineArgs(
    public val baselineName: Output<String>? = null,
    public val latestScan: Output<Boolean>? = null,
    public val resourceGroupName: Output<String>? = null,
    public val results: Output<List<List<String>>>? = null,
    public val ruleId: Output<String>? = null,
    public val serverName: Output<String>? = null,
    public val systemDatabaseName: Output<String>? = null,
    public val vulnerabilityAssessmentName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.sql.SqlVulnerabilityAssessmentRuleBaselineArgs> {
    override fun toJava(): com.pulumi.azurenative.sql.SqlVulnerabilityAssessmentRuleBaselineArgs =
        com.pulumi.azurenative.sql.SqlVulnerabilityAssessmentRuleBaselineArgs.builder()
            .baselineName(baselineName?.applyValue({ args0 -> args0 }))
            .latestScan(latestScan?.applyValue({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 }))
            .results(results?.applyValue({ args0 -> args0.map({ args0 -> args0.map({ args0 -> args0 }) }) }))
            .ruleId(ruleId?.applyValue({ args0 -> args0 }))
            .serverName(serverName?.applyValue({ args0 -> args0 }))
            .systemDatabaseName(systemDatabaseName?.applyValue({ args0 -> args0 }))
            .vulnerabilityAssessmentName(vulnerabilityAssessmentName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SqlVulnerabilityAssessmentRuleBaselineArgs].
 */
@PulumiTagMarker
public class SqlVulnerabilityAssessmentRuleBaselineArgsBuilder internal constructor() {
    private var baselineName: Output<String>? = null

    private var latestScan: Output<Boolean>? = null

    private var resourceGroupName: Output<String>? = null

    private var results: Output<List<List<String>>>? = null

    private var ruleId: Output<String>? = null

    private var serverName: Output<String>? = null

    private var systemDatabaseName: Output<String>? = null

    private var vulnerabilityAssessmentName: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("kndqhdxpfqwyneyw")
    public suspend fun baselineName(`value`: Output<String>) {
        this.baselineName = value
    }

    /**
     * @param value The latest scan flag
     */
    @JvmName("qoslxqetujvwdosh")
    public suspend fun latestScan(`value`: Output<Boolean>) {
        this.latestScan = value
    }

    /**
     * @param value The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
     */
    @JvmName("wuquxuaxhvdaoaff")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value The rule baseline result
     */
    @JvmName("duymyywyipyytbib")
    public suspend fun results(`value`: Output<List<List<String>>>) {
        this.results = value
    }

    @JvmName("vorpqmvwwpudistj")
    public suspend fun results(vararg values: Output<List<String>>) {
        this.results = Output.all(values.asList())
    }

    /**
     * @param values The rule baseline result
     */
    @JvmName("vkbumrbkpweavkln")
    public suspend fun results(values: List<Output<List<String>>>) {
        this.results = Output.all(values)
    }

    /**
     * @param value The vulnerability assessment rule ID.
     */
    @JvmName("rjgfxbdcnjyxymfy")
    public suspend fun ruleId(`value`: Output<String>) {
        this.ruleId = value
    }

    /**
     * @param value The name of the server.
     */
    @JvmName("reiyaypaejdqepmc")
    public suspend fun serverName(`value`: Output<String>) {
        this.serverName = value
    }

    /**
     * @param value The vulnerability assessment system database name.
     */
    @JvmName("eslrvbhpqydmrmkt")
    public suspend fun systemDatabaseName(`value`: Output<String>) {
        this.systemDatabaseName = value
    }

    /**
     * @param value The name of the vulnerability assessment.
     */
    @JvmName("firtujkjjrqgoiym")
    public suspend fun vulnerabilityAssessmentName(`value`: Output<String>) {
        this.vulnerabilityAssessmentName = value
    }

    /**
     * @param value
     */
    @JvmName("qcxpihbofbimtjdp")
    public suspend fun baselineName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.baselineName = mapped
    }

    /**
     * @param value The latest scan flag
     */
    @JvmName("fhrpqsergxynbyox")
    public suspend fun latestScan(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.latestScan = mapped
    }

    /**
     * @param value The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
     */
    @JvmName("wmhwvshvmeycvgpd")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The rule baseline result
     */
    @JvmName("gurwrkxffinrqgcd")
    public suspend fun results(`value`: List<List<String>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.results = mapped
    }

    /**
     * @param values The rule baseline result
     */
    @JvmName("qjqhynolqhaktckv")
    public suspend fun results(vararg values: List<String>) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.results = mapped
    }

    /**
     * @param value The vulnerability assessment rule ID.
     */
    @JvmName("jxwowoujhekyutgy")
    public suspend fun ruleId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ruleId = mapped
    }

    /**
     * @param value The name of the server.
     */
    @JvmName("ojmwkmgkdcquuhht")
    public suspend fun serverName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serverName = mapped
    }

    /**
     * @param value The vulnerability assessment system database name.
     */
    @JvmName("fsjjyjqvdslxslru")
    public suspend fun systemDatabaseName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.systemDatabaseName = mapped
    }

    /**
     * @param value The name of the vulnerability assessment.
     */
    @JvmName("uhxrnajddykdrktp")
    public suspend fun vulnerabilityAssessmentName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.vulnerabilityAssessmentName = mapped
    }

    internal fun build(): SqlVulnerabilityAssessmentRuleBaselineArgs =
        SqlVulnerabilityAssessmentRuleBaselineArgs(
            baselineName = baselineName,
            latestScan = latestScan,
            resourceGroupName = resourceGroupName,
            results = results,
            ruleId = ruleId,
            serverName = serverName,
            systemDatabaseName = systemDatabaseName,
            vulnerabilityAssessmentName = vulnerabilityAssessmentName,
        )
}
